==> modx-2.1.5-pl-ja.zip: modx-2.1.5-pl-ja/core/lexicon/ja/chunk.inc.php <==
<?php
/**
 * Chunk Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['chunk'] = 'チャンク';
$_lang['chunk_desc_category'] = 'The Category this Chunk belongs in.';
$_lang['chunk_desc_description'] = 'A short description of this chunk.';
$_lang['chunk_desc_name'] = 'The name of this chunk. It will be available using the [[$nameOfChunk]] tags.';
$_lang['chunk_code'] = 'チャンク コード (html)';
$_lang['chunk_desc'] = '説明';
$_lang['chunk_delete_confirm'] = 'このチャンクを本当に削除しますか？';
$_lang['chunk_duplicate_confirm'] = 'このチャンクを複製しますか？';
$_lang['chunk_err_duplicate'] = 'チャンクの複製に失敗しました。';
$_lang['chunk_err_exists_name'] = '[[+name]]という名前のチャンクがすでに存在します。';
$_lang['chunk_err_invalid_name'] = '無効なチャンク名です。';
$_lang['chunk_err_locked'] = 'チャンクはロックされています。';
$_lang['chunk_err_remove'] = 'チャンクの削除中にエラーが発生しました。';
$_lang['chunk_err_save'] = 'チャンクの保存中にエラーが発生しました。';
$_lang['chunk_err_nf'] = 'チャンクが見つかりません';
$_lang['chunk_err_nfs'] = 'ID [[+id]]のチャンクが見つかりません。';
$_lang['chunk_err_ns'] = 'チャンクが指定されていません。';
$_lang['chunk_err_ns_name'] = 'チャンク名を指定してください。';
$_lang['chunk_lock'] = 'チャンクは編集中のためロックされています。';
$_lang['chunk_lock_msg'] = 'このチャンクを編集するためにはロックの解除が必要です。';
$_lang['chunk_msg'] = 'チャンクの追加・編集が可能です。チャンクはHTMLコードとして動作するため、PHPのコードは無効となります。';
$_lang['chunk_name'] = 'チャンク名';
$_lang['chunk_new'] = '新しいチャンク';
$_lang['chunk_properties'] = '既定のプロパティ';
$_lang['chunk_title'] = 'チャンクの新規作成/編集';
$_lang['chunk_untitled'] = '無名のチャンク';
$_lang['chunks'] = 'チャンク';

==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/chunk.inc.php <==
<?php
/**
* Chunk Japanese lexicon topic
*
* @language ja
* @package modx
* @subpackage lexicon
* @author Nick http://smallworld.west-tokyo.com
* @author shimojo http://www.priqia.com/
* @author yamamoto http://kyms.jp
* @author honda http://kogus.org
*/
$_lang['chunk'] = 'チャンク';
$_lang['chunk_desc_category'] = 'このチャンクが属するカテゴリーを選択して下さい。';
$_lang['chunk_desc_description'] = 'このチャンクの短い説明を入力してください。';
$_lang['chunk_desc_name'] = 'このチャンクの名前を指定してください。[[$チャンク名]]というタグによってチャンクを使用します。';
$_lang['chunk_code'] = 'チャンク コード (html)';
$_lang['chunk_desc'] = '説明';
$_lang['chunk_delete_confirm'] = 'このチャンクを本当に削除しますか？';
$_lang['chunk_duplicate_confirm'] = 'このチャンクを複製しますか？';
$_lang['chunk_err_duplicate'] = 'チャンクの複製に失敗しました。';
$_lang['chunk_err_exists_name'] = '[[+name]]という名前のチャンクがすでに存在します。';
$_lang['chunk_err_invalid_name'] = '無効なチャンク名です。';
$_lang['chunk_err_locked'] = 'チャンクはロックされています。';
$_lang['chunk_err_remove'] = 'チャンクの削除中にエラーが発生しました。';
$_lang['chunk_err_save'] = 'チャンクの保存中にエラーが発生しました。';
$_lang['chunk_err_nf'] = 'チャンクが見つかりません';
$_lang['chunk_err_nfs'] = 'ID [[+id]]のチャンクが見つかりません。';
$_lang['chunk_err_ns'] = 'チャンクが指定されていません。';
$_lang['chunk_err_ns_name'] = 'チャンク名を指定してください。';
$_lang['chunk_lock'] = 'チャンクは編集中のためロックされています。';
$_lang['chunk_lock_msg'] = 'このチャンクを編集するためにはロックの解除が必要です。';
$_lang['chunk_msg'] = 'チャンクの追加・編集が可能です。チャンクはHTMLコードとして動作するため、PHPのコードは無効となります。';
$_lang['chunk_name'] = 'チャンク名';
$_lang['chunk_new'] = '新しいチャンク';
$_lang['chunk_properties'] = '既定のプロパティ';
$_lang['chunk_title'] = 'チャンクの新規作成/編集';
$_lang['chunk_untitled'] = '無名のチャンク';
$_lang['chunks'] = 'チャンク';
